/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*-
 * vim: set ts=8 sts=2 et sw=2 tw=80:
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef fuzz_tests_tests_h
#define fuzz_tests_tests_h

#include <errno.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

#include "FuzzingInterface.h"

#include "vm/JSContext.h"

#endif /* fuzz_tests_tests_h */
