// Copyright 2022 Mathias Bynens. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
author: Mathias Bynens
esid: prod-PrivateIdentifier
description: |
  Test that Unicode v12.0.0 ID_Start characters are accepted as
  identifier start characters in private class fields.
info: |
  Generated by https://github.com/mathiasbynens/caniunicode
features: [class, class-fields-private]
---*/

class _ {
  #ຆ;
  #ຉ;
  #ຌ;
  #ຎ;
  #ຏ;
  #ຐ;
  #ຑ;
  #ຒ;
  #ຓ;
  #ຘ;
  #ຠ;
  #ຨ;
  #ຩ;
  #ຬ;
  #ᳲ;
  #ᳳ;
  #ᳺ;
  #Ꞻ;
  #ꞻ;
  #Ꞽ;
  #ꞽ;
  #Ꞿ;
  #ꞿ;
  #Ꟃ;
  #ꟃ;
  #Ꞔ;
  #Ʂ;
  #Ᶎ;
  #ꭦ;
  #ꭧ;
  #𐿠;
  #𐿡;
  #𐿢;
  #𐿣;
  #𐿤;
  #𐿥;
  #𐿦;
  #𐿧;
  #𐿨;
  #𐿩;
  #𐿪;
  #𐿫;
  #𐿬;
  #𐿭;
  #𐿮;
  #𐿯;
  #𐿰;
  #𐿱;
  #𐿲;
  #𐿳;
  #𐿴;
  #𐿵;
  #𐿶;
  #𑑟;
  #𑚸;
  #𑦠;
  #𑦡;
  #𑦢;
  #𑦣;
  #𑦤;
  #𑦥;
  #𑦦;
  #𑦧;
  #𑦪;
  #𑦫;
  #𑦬;
  #𑦭;
  #𑦮;
  #𑦯;
  #𑦰;
  #𑦱;
  #𑦲;
  #𑦳;
  #𑦴;
  #𑦵;
  #𑦶;
  #𑦷;
  #𑦸;
  #𑦹;
  #𑦺;
  #𑦻;
  #𑦼;
  #𑦽;
  #𑦾;
  #𑦿;
  #𑧀;
  #𑧁;
  #𑧂;
  #𑧃;
  #𑧄;
  #𑧅;
  #𑧆;
  #𑧇;
  #𑧈;
  #𑧉;
  #𑧊;
  #𑧋;
  #𑧌;
  #𑧍;
  #𑧎;
  #𑧏;
  #𑧐;
  #𑧡;
  #𑧣;
  #𑪄;
  #𑪅;
  #𖽅;
  #𖽆;
  #𖽇;
  #𖽈;
  #𖽉;
  #𖽊;
  #𖿣;
  #𘟲;
  #𘟳;
  #𘟴;
  #𘟵;
  #𘟶;
  #𘟷;
  #𛅐;
  #𛅑;
  #𛅒;
  #𛅤;
  #𛅥;
  #𛅦;
  #𛅧;
  #𞄀;
  #𞄁;
  #𞄂;
  #𞄃;
  #𞄄;
  #𞄅;
  #𞄆;
  #𞄇;
  #𞄈;
  #𞄉;
  #𞄊;
  #𞄋;
  #𞄌;
  #𞄍;
  #𞄎;
  #𞄏;
  #𞄐;
  #𞄑;
  #𞄒;
  #𞄓;
  #𞄔;
  #𞄕;
  #𞄖;
  #𞄗;
  #𞄘;
  #𞄙;
  #𞄚;
  #𞄛;
  #𞄜;
  #𞄝;
  #𞄞;
  #𞄟;
  #𞄠;
  #𞄡;
  #𞄢;
  #𞄣;
  #𞄤;
  #𞄥;
  #𞄦;
  #𞄧;
  #𞄨;
  #𞄩;
  #𞄪;
  #𞄫;
  #𞄬;
  #𞄷;
  #𞄸;
  #𞄹;
  #𞄺;
  #𞄻;
  #𞄼;
  #𞄽;
  #𞅎;
  #𞋀;
  #𞋁;
  #𞋂;
  #𞋃;
  #𞋄;
  #𞋅;
  #𞋆;
  #𞋇;
  #𞋈;
  #𞋉;
  #𞋊;
  #𞋋;
  #𞋌;
  #𞋍;
  #𞋎;
  #𞋏;
  #𞋐;
  #𞋑;
  #𞋒;
  #𞋓;
  #𞋔;
  #𞋕;
  #𞋖;
  #𞋗;
  #𞋘;
  #𞋙;
  #𞋚;
  #𞋛;
  #𞋜;
  #𞋝;
  #𞋞;
  #𞋟;
  #𞋠;
  #𞋡;
  #𞋢;
  #𞋣;
  #𞋤;
  #𞋥;
  #𞋦;
  #𞋧;
  #𞋨;
  #𞋩;
  #𞋪;
  #𞋫;
  #𞥋;
};

reportCompare(0, 0);
