// This file was procedurally generated from the following sources:
// - src/assignment-target-type/identifierreference-eval.case
// - src/assignment-target-type/simple/basic/default.template
/*---
description: IdentifierReference Identifier, Return simple. (Simple Direct assignment)
flags: [generated, noStrict]
---*/


eval = 1;

reportCompare(0, 0);
