// |reftest| error:SyntaxError
// Copyright (C) 2018 André Bargull. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
esid: sec-async-arrow-function-definitions
description: >
  It is a SyntaxError if FormalParameters' default expressions contains await.
negative:
  phase: parse
  type: SyntaxError
features: [async-functions]
---*/

$DONOTEVALUATE();

async(a = (await) => {}) => {};
