// |reftest| skip -- not a test file
// Copyright (C) 2016 the V8 project authors. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

var x = null;
export { x as default };
