// |reftest| skip -- not a test file
// Copyright (C) 2018 Leo Balter. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

export function valueOf() {
    return 42;
}
