// |reftest| skip -- not a test file
// Copyright (C) 2018 Valerie Young. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

Function('return this;')().test262 += '9';
