// |reftest| skip -- not a test file
// Copyright (C) 2020 Ecma International. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

import { evaluated } from './verify-dfs.js';

evaluated('B');
