#! these characters should be treated as a comment

// Copyright (C) 2019 Leo Balter. All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
esid: pending
description: >
    Hashbang comments should be allowed in Scripts and should not be required to be empty.
info: |
    HashbangComment::
      #! SingleLineCommentChars[opt]
flags: [raw]
features: [hashbang]
---*/

reportCompare(0, 0);
