// |reftest| error:SyntaxError
// Copyright 2019 Mike Pennisi.  All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/*---
esid: sec-line-terminators
es5id: 7.3-7
description: >
    7.3 - ES5 recognizes the character <LF> (\u000A) as terminating
    regular expression literals
negative:
  phase: parse
  type: SyntaxError
---*/

$DONOTEVALUATE();

/
/
